leiningen.gzip-resources


gzip-fileclj

(gzip-file [input output])

gzip-resourcesclj

(gzip-resources project & [opts])

Find and gzip resources. Generates an gzipped file of every resource. Generated file name is same as the resource name with ".gz" appended to it.

Accepts an optional map of following options: :target - Target path, defaults to project :target :resource-paths - Seq of resource paths, defaults to project :resource-paths

Find and gzip resources. Generates an gzipped file of every resource. Generated
file name is same as the resource name with ".gz" appended to it.

Accepts an optional map of following options:
  :target          - Target path, defaults to project :target
  :resource-paths  - Seq of resource paths, defaults to project :resource-paths
raw docstring

mkdirsclj

(mkdirs f)

regular-file?clj

(regular-file? file)

relativizeclj

(relativize file base)

target-fileclj

(target-file base target file)

cljdoc builds & hosts documentation for Clojure/Script libraries