(gzip-file [input output])(gzip-resources project & [opts])Find and gzip resources. Generates an gzipped file of every resource. Generated file name is same as the resource name with ".gz" appended to it.
Accepts an optional map of following options: :target - Target path, defaults to project :target :resource-paths - Seq of resource paths, defaults to project :resource-paths
Find and gzip resources. Generates an gzipped file of every resource. Generated file name is same as the resource name with ".gz" appended to it. Accepts an optional map of following options: :target - Target path, defaults to project :target :resource-paths - Seq of resource paths, defaults to project :resource-paths
(mkdirs f)(regular-file? file)(relativize file base)(target-file base target file)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |